@@ -7,7 +7,7 @@ function(par, ylist, Slist, kXlist, nalist, nobs, k) {
 	U <- t(L)
 	Psi <- crossprod(U)
 
-	# GET THE ESTIMATE OF beta CONDITIONAL ON Psi_theta
+	# GET THE ESTIMATE OF coef CONDITIONAL ON Psi_theta
 	Sigmalist <- mapply(function(S,na) S+Psi[na,na,drop=FALSE],
 		Slist,nalist,SIMPLIFY=FALSE)
 	Ulist <- lapply(Sigmalist,chol)
@@ -18,7 +18,7 @@ function(par, ylist, Slist, kXlist, nalist, nobs, k) {
 		invUlist,ylist,SIMPLIFY=FALSE)
 	invtUX <- rbindlist(invtUXlist)
 	invtUy <- rbindlist(invtUylist)
-	beta <- as.numeric(qr.solve(invtUX,invtUy))
+	coef <- as.numeric(qr.solve(invtUX,invtUy))
 
 	# COMPUTE THE MATRIX DERIVATIVES OF EACH PARAMETER
 	Dlist <- lapply(seq(length(par)),gradchol,k,U)
@@ -27,7 +27,7 @@ function(par, ylist, Slist, kXlist, nalist, nobs, k) {
 	fgrad <- function(D,y,kX,invU,na) {
 		sum(mapply(function(y,kX,invU,na) {
 			invSigma <- tcrossprod(invU)
-			res <- as.numeric(y-kX%*%beta)
+			res <- as.numeric(y-kX%*%coef)
 			A <- crossprod(res,invSigma)%*%D[na,na]%*%invSigma%*%res
 			B <- sum(diag(invSigma%*%D[na,na]))
 			return(as.numeric(0.5*(A-B)))},y,kX,invU,na))
